#ifndef KXPANELDOCK_H
#define KXPANELDOCK_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qtimer.h>
#include <qwidget.h>
#include <qpixmap.h>
#include <qlabel.h>
#include <v2_codes.h>
#include <qsize.h>
#include <qpoint.h>

class kxPanelDock : public QLabel
{
  Q_OBJECT
public:
  kxPanelDock();

  QTimer blinkTimer;  
  QPixmap pixmap;

  QString status;
  QString message;
  int icon;
  bool showIcon;
  
  int showMessage();
  void paintWM();
  
public slots:
  void SlotTimeout();
  void SlotUpdatePixmap();  
  void SlotRecount(UIN); 
  void SlotShowMessage();  
protected:
  void paintEvent(QPaintEvent *);
  void mousePressEvent(QMouseEvent *);
  
};

#endif

